summaryrefslogtreecommitdiffstats
path: root/conduits/abbrowserconduit/resolutionDialog.cc
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit9abdf0551e3660f55791ce3720d5f7035c06aa19 (patch)
tree30466a53042f3fd9ff5d3e4db0dc1120d0d8648b /conduits/abbrowserconduit/resolutionDialog.cc
parent539a35866f0bac8f00e493654d4a8ec6863726e2 (diff)
downloadkpilot-9abdf0551e3660f55791ce3720d5f7035c06aa19.tar.gz
kpilot-9abdf0551e3660f55791ce3720d5f7035c06aa19.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kpilot@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'conduits/abbrowserconduit/resolutionDialog.cc')
-rw-r--r--conduits/abbrowserconduit/resolutionDialog.cc20
1 files changed, 10 insertions, 10 deletions
diff --git a/conduits/abbrowserconduit/resolutionDialog.cc b/conduits/abbrowserconduit/resolutionDialog.cc
index ca61afe..34e1fb4 100644
--- a/conduits/abbrowserconduit/resolutionDialog.cc
+++ b/conduits/abbrowserconduit/resolutionDialog.cc
@@ -43,15 +43,15 @@
* as well as its child radio buttons. There are two different constructors
* for them.
* Each controller has three child radio buttons, and if any of them is
* activated (stateChange), it sets the text of its tqparent (which is the
* controller, which is an instance of ResolutionCheckListItem, too).
**/
class ResolutionCheckListItem : TQCheckListItem {
public:
ResolutionCheckListItem(ResolutionItem*it, ResolutionTable*tb,
- TQListView*tqparent);
+ TQListView*parent);
ResolutionCheckListItem(TQString header, TQString text,
- ResolutionCheckListItem*tqparent);
+ ResolutionCheckListItem*parent);
~ResolutionCheckListItem() {};
virtual void stateChange(bool newstate);
virtual void setValue(TQString text);
@@ -73,8 +73,8 @@ protected:
ResolutionCheckListItem::ResolutionCheckListItem(ResolutionItem*it,
- ResolutionTable*tb, TQListView*tqparent) :
- TQCheckListItem(tqparent, TQString(), TQCheckListItem::Controller),
+ ResolutionTable*tb, TQListView*parent) :
+ TQCheckListItem(parent, TQString(), TQCheckListItem::Controller),
fResItem(it),
isController(true),
fCaption(it?(it->fName):(TQString())),
@@ -119,8 +119,8 @@ ResolutionCheckListItem::ResolutionCheckListItem(ResolutionItem*it,
}
ResolutionCheckListItem::ResolutionCheckListItem(TQString text, TQString header,
- ResolutionCheckListItem*tqparent) :
- TQCheckListItem(tqparent, TQString(), TQCheckListItem::RadioButton),
+ ResolutionCheckListItem*parent) :
+ TQCheckListItem(parent, TQString(), TQCheckListItem::RadioButton),
fResItem(0L),
isController(false),
fCaption(header),
@@ -133,7 +133,7 @@ void ResolutionCheckListItem::stateChange(bool newstate)
{
if (newstate && !isController)
{
- ResolutionCheckListItem*par=static_cast<ResolutionCheckListItem*>(tqparent());
+ ResolutionCheckListItem*par=static_cast<ResolutionCheckListItem*>(parent());
{
par->setValue(fText);
}
@@ -171,9 +171,9 @@ void ResolutionCheckListItem::updateText()
*
*****************************************************************/
-ResolutionDlg::ResolutionDlg( TQWidget* tqparent, KPilotLink*fH,
+ResolutionDlg::ResolutionDlg( TQWidget* parent, KPilotLink*fH,
const TQString &caption, const TQString &helpText, ResolutionTable*tab) :
- KDialogBase( tqparent, "ResolutionDlg", false, caption, Apply|Cancel, Apply),
+ KDialogBase( parent, "ResolutionDlg", false, caption, Apply|Cancel, Apply),
tickleTimer(0L),
fHandle(fH),
fTable(tab)
@@ -43,15 +43,15 @@
* for them.
* Each controller has three child radio buttons, and if any of them is
- * activated (stateChange), it sets the text of its tqparent (which is the
+ * activated (stateChange), it sets the text of its parent (which is the
* controller, which is an instance of ResolutionCheckListItem, too).
**/